==> localnews-msg-facade-1.3.7-sources.jar: com/bxm/localnews/mq/facade/controller/MessageFacadeController.java <==
package com.bxm.localnews.mq.facade.controller;

import com.bxm.localnews.mq.common.model.dto.PushMessage;
import com.bxm.localnews.mq.consume.service.MessageService;
import com.bxm.localnews.mq.consume.service.MessageUserService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * @author zhaoyadong 2019/3/7 17:15
 * @desc
 */
@Api(tags = "5-90 用户消息列表", description = "获取用户的消息")
@RestController
@RequestMapping("/facade/msg")
public class MessageFacadeController {

    @Autowired
    private MessageUserService messageUserService;

    @Autowired
    private MessageService messageService;

    @ApiOperation(value = "5-90-1 计算用户消息的总数，在个人中心显示", notes = "")
    @ApiImplicitParam(name = "userId", value = "用户ID", required = true)
    @RequestMapping(value = "/number", method = RequestMethod.GET)
    public ResponseEntity<Integer> countTotalMsg(@RequestParam("userId") Long userId) {
        return ResponseEntity.ok(messageUserService.countTotalMsg(userId));
    }

    @ApiOperation(value = "5-90-2 添加用户消息", notes = "")
    @RequestMapping(value = "/add", method = RequestMethod.POST)
    public ResponseEntity<Boolean> addMsg(@RequestBody PushMessage pushMessage, @RequestParam("userId") Long userId) {
        return ResponseEntity.ok(messageService.addMessage(pushMessage, userId));
    }
}

==> localnews-msg-facade-1.3.9-sources.jar: com/bxm/localnews/mq/facade/controller/MessageFacadeController.java <==
package com.bxm.localnews.mq.facade.controller;

import com.bxm.localnews.mq.common.model.dto.PushMessage;
import com.bxm.localnews.mq.consume.service.MessageService;
import com.bxm.localnews.mq.consume.service.MessageUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

@Api(tags = "5-90 用户消息列表", description = "获取用户的消息")
@RestController
@RequestMapping("/facade/msg")
public class MessageFacadeController {

    private final MessageUserService messageUserService;

    private final MessageService messageService;

    @Autowired
    public MessageFacadeController(MessageUserService messageUserService, MessageService messageService) {
        this.messageUserService = messageUserService;
        this.messageService = messageService;
    }

    @ApiOperation(value = "5-90-1 计算用户消息的总数，在个人中心显示")
    @ApiImplicitParam(name = "userId", value = "用户ID", required = true)
    @RequestMapping(value = "/number", method = RequestMethod.GET)
    public ResponseEntity<Integer> countTotalMsg(@RequestParam("userId") Long userId) {
        return ResponseEntity.ok(messageUserService.countTotalMsg(userId));
    }

    @ApiOperation(value = "5-90-2 添加用户消息")
    @RequestMapping(value = "/add", method = RequestMethod.POST)
    public ResponseEntity<Boolean> addMsg(@RequestBody PushMessage pushMessage, @RequestParam("userId") Long userId) {
        return ResponseEntity.ok(messageService.addMessage(pushMessage, userId));
    }
}
